(* ****************************************************************************
 *                         Fumio Kawamata's J2j
 *                         A Thumbnail Generator
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit html;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, StdCtrls, ExtCtrls, Buttons, Spin;

type
  TformHTML = class(TForm)
    bitbtnExit                  : TBitBtn;
    checkboxDateTime            : TCheckBox;
    checkboxFileSize            : TCheckBox;
    checkboxName                : TCheckBox;
    checkboxPictureSize         : TCheckBox;
    editBODYOption              : TEdit;
    editComment                 : TEdit;
    editIndexExt                : TEdit;
    editIndexName               : TEdit;
    editMaintainerEmail         : TEdit;
    editMaintainerName          : TEdit;
    editTABLEOption             : TEdit;
    editTitle                   : TEdit;
    groupboxMaintainerName: TGroupBox;
    groupboxMaintainerEmail: TGroupBox;
    groupboxBODY                : TGroupBox;
    groupboxComment             : TGroupBox;
    groupboxHEAD                : TGroupBox;
    groupboxHTMLFileName        : TGroupBox;
    groupboxJPEG                : TGroupBox;
    groupboxTABLE               : TGroupBox;
    groupboxTableLayout         : TGroupBox;
    groupboxTitle               : TGroupBox;
    labelColumn                 : TLabel;
    labelDot                    : TLabel;
    labelRow                    : TLabel;
    memoHEADBlock               : TMemo;
    pagecontrolHTML             : TPageControl;
    radiogroupSingleMultiPage   : TRadioGroup;
    tabsheetBasic               : TTabSheet;
    tabsheetExpert              : TTabSheet;
    spineditColumn: TSpinEdit;
    spineditRow: TSpinEdit;
    CheckBoxTimeStamp: TCheckBox;
    CheckBoxNewPage: TCheckBox;
    procedure editColumnChange(Sender: TObject);
    procedure editRowChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure editIndexNameChange(Sender: TObject);
    procedure editIndexExtChange(Sender: TObject);
    procedure radiogroupSingleMultiPageClick(Sender: TObject);
  private
    procedure RestoreOptionStatus;
    procedure StoreOptionStatus;
  public
  end;

var
  formHTML: TformHTML;

implementation

{$R *.DFM}
uses
  RegUtl,Registry;
const
  BaseKeyName = '\software\Fumio_Kawamata_J2j';


procedure TformHTML.StoreOptionStatus;
(* ****************************************************************************
 * Stores option statuses such as form position, wait time, panel layout, etc.
 * ****************************************************************************
 *)
var
//    MinFileSize : LongInt;
    Reg         : TRegIniFile;
    SubKeyName  : String;
begin
  SubKeyName:=formHTML.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);

  Reg.WriteString(SubKeyName,'Title',editTitle.Text);
  Reg.WriteString(SubKeyName,'Comment',editComment.Text);
  Reg.WriteString(SubKeyName,'Column',spineditColumn.Text);
  Reg.WriteString(SubKeyName,'Row',spineditRow.Text);
  Reg.WriteString(SubKeyName,'IndexName',editIndexName.Text);
  Reg.WriteString(SubKeyName,'IndexExt',editIndexExt.Text);
  Reg.WriteString(SubKeyName,'MaintainerName',editMaintainerName.Text);
  Reg.WriteString(SubKeyName,'MaintainerEmail',editMaintainerEmail.Text);
  Reg.WriteString(SubKeyName,'BODYOption',editBODYOption.Text);
  Reg.WriteString(SubKeyName,'TABLEOption',editTABLEOption.Text);
  Reg.WriteString(SubKeyName,'HEADBlock',memoHEADBlock.Text);


  Reg.WriteInteger(SubKeyName,'SingleMultiPage',radiogroupSingleMultiPage.ItemIndex);

  Reg.WriteBool(SubKeyName,'NameInfo',checkboxName.Checked);
  Reg.WriteBool(SubKeyName,'FileSizeInfo',checkboxFileSize.Checked);
  Reg.WriteBool(SubKeyName,'PictureSizeInfo',checkboxPictureSize.Checked);
  Reg.WriteBool(SubKeyName,'DateAndTime',checkboxDateTime.Checked);
  Reg.WriteBool(SubKeyName, 'TimeStamp', checkboxTimeStamp.Checked);
  Reg.WriteBool(SubKeyName, 'DisplayInNewPage', checkboxNewPage.Checked);

  Reg.Free;
end;


procedure TformHTML.RestoreOptionStatus;
(* ****************************************************************************
 * Restores option statuses which are stored by "StoreOptionStatus" procedure.
 * ****************************************************************************
 *)
var
    Reg                 : TRegIniFile;
    SubKeyName          : String;
begin
  SubKeyName:=formHTML.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);

  editTitle.Text:=Reg.ReadString(SubKeyName,'Title', 'JPEG File Catalog');
  editComment.Text:=Reg.ReadString(SubKeyName,'Comment','');
  spineditColumn.Text:=Reg.ReadString(SubKeyName,'Column', '4');
  spineditRow.Text:=Reg.ReadString(SubKeyName,'Row', '5');
  editIndexName.Text:=Reg.ReadString(SubKeyName,'IndexName','index');
  editIndexExt.Text:=Reg.ReadString(SubKeyName,'IndexExt','html');
  editMaintainerName.Text:=Reg.ReadString(SubKeyName,'MaintainerName','');
  editMaintainerEmail.Text:=Reg.ReadString(SubKeyName,'MaintainerEmail','');
  editBODYOption.Text:=Reg.ReadString(SubKeyName,'BODYOption','');
  editTABLEOption.Text:=Reg.ReadString(SubKeyName,'TABLEOption','BORDER="1" CELLSPACING="0" CELLPADDING="5"');
  memoHEADBlock.Text:=Reg.ReadString(SubKeyName,'HEADBlock','');

  radiogroupSingleMultiPage.ItemIndex:=Reg.ReadInteger(SubKeyName,'SingleMultiPage',0);

  checkboxName.Checked:=Reg.ReadBool(SubKeyName,'NameInfo',True);
  checkboxFileSize.Checked:=Reg.ReadBool(SubKeyName,'FileSizeInfo',True);
  checkboxPictureSize.Checked:=Reg.ReadBool(SubKeyName,'PictureSizeInfo',True);
  checkboxDateTime.Checked:=Reg.ReadBool(SubKeyName,'DateAndTime',True);

  checkboxTimeStamp.Checked:=Reg.ReadBool(SubKeyName, 'TimeStamp', True);
  checkboxNewPage.Checked:=Reg.ReadBool(SubKeyName, 'DisplayInNewPage', False);

  Reg.Free;
  formHTML.Update;
end;

procedure TformHTML.FormCreate(Sender: TObject);
(* ****************************************************************************
 * Sets initial values.
 * ****************************************************************************
 *)
begin
  if not(ExistKey(BaseKeyName)) then Create_Key(BaseKeyName);
  if ExistKey(BaseKeyName+'\'+formHTML.Name) then begin
    RestoreFormStatus(formHTML,BaseKeyName);
  end
  else begin
    Position:=poScreenCenter;
  end;
  RestoreOptionStatus;
  //pagecontrolHTML.ActivePage := TTabsheet(tabsheetBasic.TabIndex);
end;

procedure TformHTML.FormDestroy(Sender: TObject);
(* ****************************************************************************
 * Stores option statuses when the registories have been existed.
 * Please note users can remove the registories for this program when it is
 * running.
 * ****************************************************************************
 *)
begin
  if ExistKey(BaseKeyName) then begin
    StoreFormStatus(formHTML,BaseKeyName);
    StoreOptionStatus;
  end;
end;

procedure TformHTML.editColumnChange(Sender: TObject);
begin
  try
    StrToInt(spineditColumn.Text);
  except
    spineditColumn.Text:='4';
  end;
end;

procedure TformHTML.editRowChange(Sender: TObject);
begin
  try
    StrToInt(spineditRow.Text);
  except
    spineditRow.Text:='5';
  end;
end;

procedure TformHTML.editIndexNameChange(Sender: TObject);
begin
  if editIndexName.Text='' then editIndexName.Text:='index';
end;

procedure TformHTML.editIndexExtChange(Sender: TObject);
begin
  if editIndexExt.Text='' then editIndexExt.Text:='html';
end;

procedure TformHTML.radiogroupSingleMultiPageClick(Sender: TObject);
begin
  if radiogroupSingleMultiPage.ItemIndex=1 then begin
    labelRow.Enabled:=True;
    spineditRow.Enabled:=True;
  end
  else begin
    labelRow.Enabled:=False;
    spineditRow.Enabled:=False;
  end;
end;

end.
