(* ****************************************************************************
 *                         Fumio Kawamata's J2j
 *                         A Thumbnail Generator
 *                  Copyright (C) 1998 Fumio Kawamata
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-
 *  ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 *  Public License in the directory "manual" for more details.
 ******************************************************************************
 *)

(* ****************************************************************************
 *
 * ****************************************************************************
 *)
unit main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Menus, ComCtrls, ExtCtrls, Buttons, FileCtrl;

type
  TformMain = class(TForm)
    bitbtnAll                   : TBitBtn;
    Break                       : TMenuItem;
    broupboxThumbnail           : TGroupBox;
    checkboxHTML                : TCheckBox;
    directorylistboxOriginal    : TDirectoryListBox;
    directorylistboxThumbnail   : TDirectoryListBox;
    drivecomboboxOriginal       : TDriveComboBox;
    editPostamble               : TEdit;
    editPreamble                : TEdit;
    editSizeX                   : TEdit;
    editSizeY                   : TEdit;
    filelistboxOriginal         : TFileListBox;
    filelistboxThumbnail        : TFileListBox;
    groupboxFileName            : TGroupBox;
    groupboxMaster              : TGroupBox;
    groupboxThumbnailSize       : TGroupBox;
    imageTitleLogo              : TImage;
    imageTmp                    : TImage;
    imageViewArea               : TImage;
    labelFilename               : TLabel;
    labelJpeg                   : TLabel;
    labelX                      : TLabel;
    labelY                      : TLabel;
    menuDisplay                 : TMenuItem;
    menuDisplayHTMLSetting      : TMenuItem;
    menuDisplayLogViewer        : TMenuItem;
    menuFile                    : TMenuItem;
    menuFileExit                : TMenuItem;
    menuFileSave                : TMenuItem;
    menuFileSelectAll           : TMenuItem;
    menuHelp                    : TMenuItem;
    menuHelpInEng               : TMenuItem;
    menuHelpInJap               : TMenuItem;
    menuHelpVersion             : TMenuItem;
    menuIgnoreSizeSetting       : TMenuItem;
    menuMain                    : TMainMenu;
    menuOption                  : TMenuItem;
    menuOptionAutoDir           : TMenuItem;
    menuOptionDeleteRegistry    : TMenuItem;
    menuOptionIgnoreSizeX       : TMenuItem;
    menuOptionIgnoreSizeY       : TMenuItem;
    menuOptionWarning           : TMenuItem;
    panelViewArea               : TPanel;
    progressbarList             : TProgressBar;
    scrollboxViewArea           : TScrollBox;
    StatusBar                   : TStatusBar;
    Panel1: TPanel;
    bitbtnHTML: TBitBtn;
    bitbtnSave: TBitBtn;
    bitbtnExit: TBitBtn;
    procedure directorylistboxOriginalChange(Sender: TObject);
    procedure directorylistboxThumbnailChange(Sender: TObject);
    procedure editSizeXExit(Sender: TObject);
    procedure editSizeYExit(Sender: TObject);
    procedure filelistboxOriginalClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure menuDisplayHTMLSettingClick(Sender: TObject);
    procedure menuDisplayLogViewerClick(Sender: TObject);
    procedure menuFileExitClick(Sender: TObject);
    procedure menuFileSaveClick(Sender: TObject);
    procedure menuFileSelectAllClick(Sender: TObject);
    procedure menuHelpInEngClick(Sender: TObject);
    procedure menuHelpInJapClick(Sender: TObject);
    procedure menuHelpVersionClick(Sender: TObject);
    procedure menuIgnoreSizeSettingClick(Sender: TObject);
    procedure menuOptionAutoDirClick(Sender: TObject);
    procedure menuOptionDeleteRegistryClick(Sender: TObject);
    procedure menuOptionWarningClick(Sender: TObject);
    procedure WriteOptions;
    procedure FormActivate(Sender: TObject);
  private
    function OpenFile(FileName: String):Boolean;
    procedure BrowseHelp(FileName:String);
    procedure SaveFile(FileName: String);
    procedure RestoreOptionStatus;
    procedure StoreOptionStatus;
  public
  end;

var
  formMain: TformMain;
  IgnoreSizeX : Integer;
  IgnoreSizeY : Integer;

implementation

{$R *.DFM}

(* Following directive ignores plathome dependent warning.
 * There is no problem because this program rund only on the Windows plathome.
 *)
{$WARN UNIT_PLATFORM OFF}

uses ImgTrans,Jpeg,VerInfo,RegUtl,Registry,ShellAPI, ignore, logview, html;

var
  AutoDir : Boolean;
  Warning : Boolean;
const
  BaseKeyName = '\software\Fumio_Kawamata_J2j';


function GetFileSize(FileName:String):LongInt;
var
  SearchRec : TSearchRec;
begin
  FindFirst(FileName, faAnyFile, SearchRec);
  GetFileSize:=SearchRec.Size;
  FindClose(SearchRec);
end;

procedure TformMain.WriteOptions;
begin
  menuOptionIgnoreSizeX.Caption:='Ignore Size X='+IntToStr(IgnoreSizeX);
  menuOptionIgnoreSizeY.Caption:='Ignore Size Y='+IntToStr(IgnoreSizeY);
  menuOptionAutoDir.Checked:=AutoDir;
  menuOptionWarning.Checked:=Warning;
end;

procedure TformMain.StoreOptionStatus;
(* ****************************************************************************
 * Stores option statuses such as form position, wait time, panel layout, etc.
 * ****************************************************************************
 *)
var
//    MinFileSize : LongInt;
    ThumbX      : Integer;
    ThumbY      : Integer;
    Reg         : TRegIniFile;
    SubKeyName  : String;
begin
  ThumbX:=StrToInt(editSizeX.Text);
  ThumbY:=StrToInt(editSizeY.Text);
  //MinFileSize:=StrToInt(editMinFileSize.Text);
  SubKeyName:=formMain.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);

  Reg.WriteString(SubKeyName,'Preamble',editPreamble.Text);
  Reg.WriteString(SubKeyName,'Postamble',editPostamble.Text);
  Reg.WriteString(SubKeyName,'Drive',drivecomboboxOriginal.Drive);
  Reg.WriteString(SubKeyName,'Directory',directorylistboxOriginal.Directory);

  Reg.WriteInteger(SubKeyName,'ThumbX',ThumbX);
  Reg.WriteInteger(SubKeyName,'ThumbY',ThumbY);
  Reg.WriteBool(SubKeyName,'AutoDir',AutoDir);
  Reg.WriteBool(SubKeyName,'Warning',Warning);
  Reg.WriteInteger(SubKeyName, 'IgnoreX',IgnoreSizeX);
  Reg.WriteInteger(SubKeyName, 'IgnoreY',IgnoreSizeY);

//  Reg.WriteInteger(SubKeyName,'MinFileSize',MinFileSize);
  Reg.Free;
end;


procedure TformMain.RestoreOptionStatus;
(* ****************************************************************************
 * Restores option statuses which are stored by "StoreOptionStatus" procedure.
 * ****************************************************************************
 *)
var
    Reg                 : TRegIniFile;
    SubKeyName          : String;
    DriveLetter : String[1];
    LastDirectory : String;
begin
  SubKeyName:=formMain.Name;
  Reg:=TRegIniFile.Create(BaseKeyName);
  editSizeX.Text:=Reg.ReadString(SubKeyName,'ThumbX', '200');
  editSizeY.Text:=Reg.ReadString(SubKeyName,'ThumbY', '200');
  editPreamble.Text:=Reg.ReadString(SubKeyName,'Preamble', '_');
  editPostamble.Text:=Reg.ReadString(SubKeyName,'Postamble', '');

  DriveLetter:=Copy(Reg.ReadString(SubKeyName,'Drive', 'C'),1,1);
  LastDirectory:=Reg.ReadString(SubKeyName,'Directory', 'C:\');
  try
    drivecomboboxOriginal.Drive:=Char(DriveLetter[1]);
    directorylistboxOriginal.Directory:=LastDirectory;
  except
    MessageDlg('Last directory,'+LastDirectory+' is not exist now.',mtWarning,[mbOK],0);
  end;
  directorylistboxThumbnail.Drive:=directorylistboxOriginal.Drive;
  directorylistboxThumbnail.Directory:=directorylistboxOriginal.Directory;


  IgnoreSizeX:=Reg.ReadInteger(SubKeyName,'IgnoreX',200);
  IgnoreSizeY:=Reg.ReadInteger(SubKeyName,'IgnoreY',200);
  //editMinFileSize.Text:=Reg.ReadString(SubKeyName,'MinFileSize', '10');
  AutoDir:=Reg.ReadBool(SubKeyName,'AutoDir', True);
  Warning:=Reg.ReadBool(SubKeyName,'Warning', False);
  Reg.Free;
  WriteOptions;
  formMain.Update;
end;





function TformMain.OpenFile(FileName: String):Boolean;
var
  Ans : Boolean;
begin
  Screen.Cursor := crHourglass;
  Ans:=False;
  try
    imageTmp.Picture.LoadFromFile(FileName);
    scrollboxViewArea.Width:=StrToInt(editsizeX.Text);
    scrollboxViewArea.Height:=StrToInt(editsizeY.Text);
    try
      imgtrans.ImageTransfer(imageTmp,imageViewArea,scrollboxViewArea,True);
      imageViewArea.Refresh;
      Ans:=True;
    except
      formLogViewer.memoLog.Lines.Add(FileName+' is corrupt.');
      if Warning then MessageDlg(FileName+' is corrupt.',mtWarning,[mbOK],0);
    end;
  except
    formLogViewer.memoLog.Lines.Add(FileName+' is corrupt.');
    if Warning then MessageDlg(FileName+' is corrupt.',mtWarning,[mbOK],0);
  end;
  Screen.Cursor := crArrow;
  OpenFile:=Ans;
end;

procedure TformMain.SaveFile(FileName: String);
var
  JPEG : TJPEGImage;
begin
  JPEG:=TJPEGImage.Create;
  JPEG.Assign(imageViewArea.Picture.Bitmap);
  JPEG.SaveToFile(FileName);
  JPEG.Free;
end;





procedure TformMain.menuFileSaveClick(Sender: TObject);
var
    Column                  : Integer;
    Count                   : Integer;
    FileTimeStamp           : TDateTime;
    FileSize                : Real;
    FirstRow                : Boolean;
    HTMLFile                : TextFile;
    HTMLFileName            : String;
    HTMLIndexDir            : String;
    HTMLOut                 : Boolean;
    HTMLThumbRelativeDir    : String;
    I                       : Integer;
    IndexExt                : String;
    IndexName               : String;
    MaintainerEmail         : String;
    MaintainerName          : String;
    MinHeight               : Integer;
    MinWidth                : Integer;
    MultiPage               : Boolean;
    NumOfDummy              : Integer;
    NumOfList               : Integer;
    NumOfPage               : Integer;
    OriginalFileName        : String;
    OriginalPath            : String;
    Page                    : Integer;
    PictPerPage             : Integer;
    PictureHeight           : Integer;
    PictureWidth            : Integer;
    PreviousPage            : Integer;
    Row                     : Integer;
    SaveFileName            : String;
    SavePath                : String;
    SelectedNumOfList       : Integer;
    Target                  : String;
    ThumbnailHeight         : Integer;
    ThumbnailWidth          : Integer;
procedure WriteHTMLHeader;
var
  I: Integer;
  NumOfLine : Integer;
  BODYOption : String;
  Title : String;
  Comment : String;
begin
  Title:=formHTML.editTitle.Text;
  Comment:=formHTML.editComment.Text;
  Writeln(HTMLFile,'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">');
  Writeln(HTMLFile,'<HTML>');
  Writeln(HTMLFile,'<!-- This HTML file is created by J2j -->');
  Writeln(HTMLFile,'<!-- J2j.exe  Copyright 1998-2006 Fumio Kawamata -->');
  Writeln(HTMLFile,'<!-- Refer http://openlab.jp/fumio/ for detail information of the J2j.exe -->');
  Writeln(HTMLFile,'<HEAD>');
  Writeln(HTMLFile,'<TITLE>'+Title+'</TITLE>');
  if MaintainerEmail<>'' then Writeln(HTMLFile,'<LINK REV="MADE" HREF="mailto:'+MaintainerEmail+'">');
  NumOfLIne:=formHTML.memoHEADBlock.Lines.Count;
  if NumOfLIne>0 then begin
    for I:=0 to NumOfLine-1 do begin
      Writeln(HTMLFile,formHTML.memoHEADBlock.Lines[I]);
    end;
  end;
  Writeln(HTMLFile,'</HEAD>');
  Write(HTMLFile,'<BODY');
  BODYOption:=formHTML.editBODYOption.Text;
  if BODYOption<>'' then Write(HTMLFile, ' '+BODYOption);
  Writeln(HTMLFile,'>');
  Writeln(HTMLFile,'<H1>'+Title+'</H1>');
  Writeln(HTMLFile,'<P>'+Comment+'</P>');
  end;

procedure WritePageNavigation;
var
  FileName : String;
  NumStr : String;
begin
  Write(HTMLFile,'<P>Page '+IntToStr(Page)+'/'+IntToStr(NumOfPage));
  if Page>1 then begin (* Top page *)
    FileName:=IndexName+'.'+IndexExt;
    Write(HTMLFile,' [<A HREF="'+FileName+'">Top</A>]');
  end;
  if Page>1 then begin (* Previous page *)
    FileName:=IndexName;
    NumStr:=IntToStr(Page-1);
    if NumStr<>'1' then FileName:=FileName+NumStr;
    FileName:=FileName+'.'+IndexExt;
    Write(HTMLFile,' [<A HREF="'+FileName+'">Previous</A>]');
  end;
  if (NumOfPage-Page>0) then begin (* Next page *)
    FileName:=IndexName;
    NumStr:=IntToStr(Page+1);
    FileName:=FileName+NumStr+'.'+IndexExt;
    Write(HTMLFile,' [<A HREF="'+FileName+'">Next</A>]');
  end;
  if (NumOfPage-Page>0) then begin (* Last page *)
    FileName:=IndexName;
    NumStr:=IntToStr(NumOfPage);
    FileName:=FileName+NumStr+'.'+IndexExt;
    Write(HTMLFile,' [<A HREF="'+FileName+'">Last</A>]');
  end;
  Writeln(HTMLFile,'</P>');
end;

procedure WriteTableHeader;
var
  TABLEOption : String;
begin
  TABLEOption:=formHTML.editTABLEOption.Text;
  Write(HTMLFile,'<TABLE');
  if TABLEOption<>'' then Write(HTMLFile,' '+TABLEOption);
  Writeln(HTMLFile,'>');
end;

procedure WriteDummy;
var
  I:Integer;
begin
  formLogViewer.memoLog.Lines.Add('Dummy Cell Insertion.');
  for I:=1 to NumOfDummy do begin
    Write(HTMLFile,'<TD>&nbsp;</TD>');
  end;
  Writeln(HTMLFile,'</TR>');
end;

procedure WriteTableFooter;
begin
  formLogViewer.memoLog.Lines.Add('Insert </TABLE> tag.');
  Writeln(HTMLFile,'</TABLE>');
end;

procedure WriteHTMLFooter;
begin
  formLogViewer.memoLog.Lines.Add('HTML Footer (Mailto and Maintainer).');
  if (MaintainerName<>'') or (MaintainerEmail<>'') then begin
    Write(HTMLFile,'<P>Maintainer: ');
    if MaintainerEmail<>'' then Write(HTMLFile,'<A HREF="mailto:'+MaintainerEmail+'">');
    if MaintainerName<>'' then Write(HTMLFile,MaintainerName);
    if MaintainerEmail<>'' then Write(HTMLFile,'</A>');
    Writeln(HTMLFile,'</P>');
  end;
  if formHTML.checkboxDateTime.Checked=True then begin
    Writeln(HTMLFile,'<P>Date: '+DateToStr(Date)+' '+TimeToStr(Time)+'</P>');
  end;
  formLogViewer.memoLog.Lines.Add('</BODY> Insertion.');
  Writeln(HTMLFile,'</BODY>');
  formLogViewer.memoLog.Lines.Add('</HTML> Insertion.');
  Writeln(HTMLFile,'</HTML>');
end;

procedure CheckPictureSize;
var
  I: Integer;
begin
  with formLogViewer.memoLog.Lines do begin
    Add('***** Check Size Log *****');
    Add('Number of files : '+IntToStr(NumOfList));
    Add('Number of Selected Files : '+IntToStr(SelectedNumOfList));
  end;

  Count:=0;
  I:=0;
  while (Count<=SelectedNumOfList)and(I<=(NumOfList -1)) do begin
    if filelistboxOriginal.Selected[I]=True then begin
      inc(Count);
      progressbarList.Position:=Count;
      OriginalPath:=directorylistboxOriginal.Directory
          + '\'+ filelistboxOriginal.Items[I];
      progressbarList.Position:=Count;
      OriginalFileName:=ExtractFileName(OriginalPath);
      StatusBar.Panels[0].Text:='Checking Picture Size ('+IntToStr(Count)+'/'+IntToStr(SelectedNumOfList)+')  '+ OriginalFileName;
      StatusBar.Update;
      if OpenFile(OriginalPath)=True then begin
        PictureHeight:=imageTmp.Picture.Height;
        PictureWidth:=imageTmp.Picture.Width;
        if (PictureHeight<=MinHeight)or(PictureWidth<=MinWidth) then begin
          formLogViewer.memoLog.Lines.Add(OriginalPath + ' is too small.  X='
              +IntToStr(PictureWidth)+'  Y='+IntToStr(PictureHeight));
          if Warning then begin
            MessageDlg(OriginalFileName+chr($0D)+'Picture size is too small.'+chr($0D)
             +'X='+IntToStr(PictureWidth)+' , Y='+IntToStr(PictureHeight),mtInformation,[mbYes],0);
          end;
          filelistboxOriginal.Selected[I]:=False;
        end;
      end
      else begin
        formLogViewer.memoLog.Lines.Add(OriginalPath + ' is corrupt.');
        if Warning then begin
          MessageDlg(OriginalFileName+chr($0D)+'File is corrupt.',mtInformation,[mbYes],0);
        end;
        filelistboxOriginal.Selected[I]:=False;
      end;
    end;
    inc(I);
    Application.ProcessMessages;
  end;
  StatusBar.Panels[0].Text:='';
end;

begin
  if (editPreamble.Text='') and (editPostamble.Text='') then begin
    MessageDlg('Preamble and Postamble are empty.',mtWarning,[mbOK],0);
    Exit;
  end;
  SelectedNumOfList:=filelistboxOriginal.SelCount;
  if SelectedNumOfList=0 then begin
    MessageDlg('No selected JPEG file.',mtWarning,[mbOK],0);
    Exit;
  end;

  HTMLOut:=checkboxHTML.Checked;

  HTMLIndexDir:=directorylistboxOriginal.Directory;
  HTMLThumbRelativeDir:=directorylistboxThumbnail.Directory;
  delete(HTMLThumbRelativeDir,1,Length(HTMLIndexDir));
  if Length(HTMLThumbRelativeDir)>0 then begin
    Delete(HTMLThumbRelativeDir,1,1);
    HTMLThumbRelativeDir:=HTMLThumbRelativeDir+'/';
  end;

  //messageDlg('Index='+HTMLIndexDir+'  Relative='+HTMLThumbRelativeDir,mtInformation,[mbOK],0);

  NumOfList:=filelistboxOriginal.Items.Count;
  progressbarList.Min:=1;
  progressbarList.Max:=NumOfList;
  MinWidth:=Main.IgnoreSizeX;
  MinHeight:=Main.IgnoreSizeY;
  formLogViewer.memoLog.Clear;

  if formHTML.CheckBoxNewPage.Checked=True then begin
    Target:=' TARGET="NEW"';
  end
  else
    Target:='';


  (* Prepare for Converting *)
  SelectedNumOfList:=filelistboxOriginal.SelCount;
  progressbarList.Max:=SelectedNumOfList;
  NumOfList:=filelistboxOriginal.Items.Count;

  if HTMLOut then CheckPictureSize; (* Disselect if it is too small *)

  SelectedNumOfList:=filelistboxOriginal.SelCount;
  if SelectedNumOfList=0 then begin
    MessageDlg('No selected JPEG file.',mtWarning,[mbOK],0);
    Exit;
  end;

  progressbarList.Max:=SelectedNumOfList;

  IndexName:=formHTML.editIndexName.Text;
  IndexExt:=formHTML.editIndexExt.Text;
  MaintainerName:=formHTML.editMaintainerName.Text;
  MaintainerEmail:=formHTML.editMaintainerEmail.Text;

  Column:=StrToInt(formHTML.spineditColumn.Text);
  Row:=StrToInt(formHTML.spineditRow.Text);
  PictPerPage:=Column*Row;
  if formHTML.radiogroupSingleMultiPage.ItemIndex=1 then MultiPage:=True else MultiPage:=False;
  NumOfPage:=(SelectedNumOfList+PictPerPage-1) div PictPerPage;
  PreviousPage:=-1;
  Count:=0;
  I:=0;
  FirstRow:=False;
  with formLogViewer.memoLog.Lines do begin
    Add('***** Conversion Log *****');
    Add('Number of Files : '+IntToStr(NumOfList));
    Add('Number of Selected Files : '+IntToStr(SelectedNumOfList));
    if HTMLOut then begin
      if MultiPage then Add('Page Mode: Multi Page')
      else Add('Page Mode: Single Page');
      Add('Column : '+IntToStr(Column));
      if MultiPage then begin
        Add('Row : '+IntToStr(Row));
        Add('Number of Page : '+IntToStr(NumOfPage));
      end;
    end;
  end;

  while (Count<=SelectedNumOfList)and(I<=(NumOfList -1)) do begin
    if filelistboxOriginal.Selected[I]=True then begin
      OriginalPath:=directorylistboxOriginal.Directory
        + '\'+ filelistboxOriginal.Items[I];
      inc(Count);


      if HTMLOut then begin
        Page:=(Count+PictPerPage-1) div PictPerPage;
        if (not(MultiPage) and (Page=1) and (PreviousPage=-1)) or (MultiPage and (PreviousPage<>Page)) then begin
          HTMLFileName:=HTMLIndexDir+'\'+IndexName;
          if (MultiPage=True) and (Page>1) then HTMLFileName:=HTMLFileName+IntToStr(Page);
          HTMLFileName:=HTMLFileName+'.'+IndexExt;
          AssignFile(HTMLFile,HTMLFileName);
          Rewrite(HTMLFile);
          WriteHTMLHeader;
          if MultiPage then WritePageNavigation;
          WriteTableHeader;
          PreviousPage:=Page;
          FirstRow:=True;
formLogViewer.memoLog.Lines.Add('FileName='+HTMLFileName);
        end;
      end;
        progressbarList.Position:=Count;
        OriginalFileName:=ExtractFileName(OriginalPath);
        StatusBar.Panels[0].Text:='Converting ('+IntToStr(Count)+'/'+IntToStr(SelectedNumOfList)+')  '+OriginalFileName;
        StatusBar.Update;
        if OpenFile(OriginalPath)=True then begin
          PictureHeight:=imageTmp.Picture.Height;
          PictureWidth:=imageTmp.Picture.Width;
          if (PictureHeight>MinHeight)and(PictureWidth>MinWidth) then begin
            ThumbnailHeight:=imageViewArea.Picture.Height;
            ThumbnailWidth:=imageViewArea.Picture.Width;
            SaveFileName:=ChangeFileExt(OriginalFileName,'');
            SaveFileName:=editPreamble.Text+SaveFileName + editPostamble.Text+ '.jpg';
            SavePath:=directorylistboxThumbnail.Directory
              + '\'+SaveFileName;
            SaveFile(SavePath);
            if HTMLOut then begin
              if ((Count-1) mod Column)=0 then begin
                Write(HTMLFile,'<TR>');
              end;
              Write(HTMLFile,'<TD ALIGN="CENTER" VALIGN="TOP">');
              Write(HTMLFile,'<A HREF="'+OriginalFileName+'"'+Target+'>');
              Write(HTMLFile,'<IMG SRC="'+HTMLThumbRelativeDir+SaveFileName+'"');
              Write(HTMLFile,' ALT="['+OriginalFileName+']"');
              Write(HTMLFile,' WIDTH="'+IntToStr(ThumbnailWidth)+'"');
              Write(HTMLFile,' HEIGHT="'+IntToStr(ThumbnailHeight)+'"');
              Write(HTMLFile,' BORDER="0">');
              Write(HTMLFile,'</A>');
              if formHTML.checkboxName.Checked then begin
                Write(HTMLFile,'<BR>'+OriginalFileName);
              end;
              if formHTML.checkboxPictureSize.Checked then begin
                Write(HTMLFile,'<BR>'+IntToStr(PictureWidth)+'x'+IntToStr(PictureHeight));
              end;
              if formHTML.checkboxFileSize.Checked then begin
                FileSize:=GetFileSize(OriginalPath);
                Write(HTMLFile,Format('<BR> %.0n Bytes',[FileSize]));
              end;
              if formHTML.checkboxTimeStamp.Checked then begin
                FileTimeStamp:=FileDateToDateTime(FileAge(OriginalPath));
                Write(HTMLFile, '<BR>'+FormatDateTime('yyyy/mm/dd hh:nn:ss', FileTimeStamp));
              end;
              Write(HTMLFile,'</TD>');
              if ((Count-1) mod Column)=(Column-1) then begin
                Writeln(HTMLFile,'</TR>');
                FirstRow:=False;
              end;
            end;
          end
          else begin
            formLogViewer.memoLog.Lines.Add(OriginalPath + ' is too small.  X='
              +IntToStr(PictureWidth)+'  Y='+IntToStr(PictureHeight));
            if Warning then begin
              MessageDlg(OriginalFileName+chr($0D)+'Picture size is too small.'+chr($0D)
                +'X='+IntToStr(PictureWidth)+' , Y='+IntToStr(PictureHeight),mtInformation,[mbYes],0);
            end;
          end;
        end
        else begin
          messagedlg('UnExpected Error.  File name is '+OriginalPath,mtWarning,[mbOK],0);
        end;
        StatusBar.Panels[0].Text:='';
        if HTMLOut then begin
          if ((Count mod PictPerPage)=0)and(Count>0)and(MultiPage) then begin
            WriteTableFooter;
            WriteHTMLFooter;
            CloseFile(HTMLFile);
          end;
        end;
      end;
    inc(I);
    Application.ProcessMessages;
  end;

  if HTMLOut then begin
    if (Count mod Column)>0 then begin
      if FirstRow then begin
        Write(HTMLFile,'</TR>');
      end
      else begin
        NumOfDummy:=Column-(Count mod Column);
        WriteDummy;
      end;
      WriteTableFooter;
      WriteHTMLFooter;
      CloseFile(HTMLFile);
    end
    else begin
      if (Count>=SelectedNumOfList)and(MultiPage) then begin
        WriteTableFooter;
        WriteHTMLFooter;
        CloseFile(HTMLFile);
      end;
      if not(MultiPage) then begin
        WriteTableFooter;
        WriteHTMLFooter;
        CloseFile(HTMLFile);
      end;
    end;

  end;
  imageViewArea.Visible:=False;
  progressbarList.Position:=0;
  filelistboxOriginal.Update;
  filelistboxThumbnail.Update;
end;



procedure TformMain.editSizeXExit(Sender: TObject);
var
  X : Integer;
begin
  X:=StrToInt(editSizeX.Text);
  if X>200 then begin
    MessageDlg('The thumbnail size X can not exeed 200.',mtWarning,[mbYes],0);
    editSizeX.SetFocus;
    editSizeX.Text:='200';
  end;
  if X<32 then begin
    MessageDlg('The thumbnail size X must be over 31.',mtWarning,[mbYes],0);
    editSizeX.SetFocus;
    editSizeX.Text:='32';
  end;
end;


procedure TformMain.editSizeYExit(Sender: TObject);
var
  Y : Integer;
begin
  Y:=StrToInt(editSizeY.Text);
  if Y>200 then begin
    MessageDlg('The thumbnail Y can not exeed 200.',mtWarning,[mbYes],0);
    editSizeY.SetFocus;
    editSizeY.Text:='200';
  end;
  if Y<32 then begin
    MessageDlg('The thumbnail Y must be over 31.',mtWarning,[mbYes],0);
    editSizeY.SetFocus;
    editSizeY.Text:='32';
  end;
end;

procedure TformMain.menuFileSelectAllClick(Sender: TObject);
var
  Count : Integer;
  I     : Integer;
begin
  Count:=filelistboxOriginal.Items.Count;
  if Count=0 then begin
    MessageDlg('There is no JPEG file in the directory.',mtWarning,[mbOK],0);
    Exit;
  end;
  for I:=0 to Count-1 do begin
    filelistboxOriginal.Selected[I]:=True;
  end;
  filelistboxOriginal.Refresh;
end;


procedure TformMain.filelistboxOriginalClick(Sender: TObject);
var
  FileName : String;
begin
  FileName:=filelistboxOriginal.FileName;
  if FileName<>'' then OpenFile(FileName);
end;

procedure TformMain.directorylistboxOriginalChange(Sender: TObject);
begin
  if AutoDir then begin
    directorylistboxThumbnail.Directory:=directorylistboxOriginal.Directory;
    directorylistboxThumbnail.Update;
  end;
end;

procedure TformMain.menuHelpVersionClick(Sender: TObject);
(* ****************************************************************************
 * Shows Version Informations.
 * ****************************************************************************
 *)
const
  CR = chr($0D);
var
  Mess : String;
begin
  Mess:=VerInfo.GetVersionInfo('ProductName')+CR
       +VerInfo.GetVersionInfo('FileDescription')+CR
       +'Version '+VerInfo.GetVersionInfo('FileVersion')+CR
       +'Copyright '+VerInfo.GetVersionInfo('LegalCopyright')+CR
       +'Homepage '+VerInfo.GetVersionInfo('Homepage');
  MessageDlg(Mess,mtInformation,[mbOK],0);
end;

procedure TformMain.FormCreate(Sender: TObject);
(* ****************************************************************************
 * Sets initial values.
 * ****************************************************************************
 *)
begin
  formMain.Caption:=formMain.Caption+'  '+GetVersionInfo('FileVersion');
  if not(ExistKey(BaseKeyName)) then Create_Key(BaseKeyName);
  if ExistKey(BaseKeyName+'\'+formMain.Name) then begin
    RestoreFormStatus(formMain,BaseKeyName);
  end
  else begin
    //Width:=600;
    //Height:=480;
    IgnoreSizeX:=200;
    IgnoreSizeY:=200;
    Position:=poScreenCenter;
    //AutoDir:=True;
    //Warning:=False;
  end;
  RestoreOptionStatus;
  WriteOptions;
end;

procedure TformMain.FormDestroy(Sender: TObject);
(* ****************************************************************************
 * Stores option statuses when the registories have been existed.
 * Please note users can remove the registories for this program when it is
 * running.
 * ****************************************************************************
 *)
begin
  if ExistKey(BaseKeyName) then begin
    StoreFormStatus(formMain,BaseKeyName);
    StoreOptionStatus;
  end;
end;


procedure DisplayResult(Code: word; FileName:string);
(* ****************************************************************************
 * Displays the result of the shellexecute command.
 * The program uses the shell exexute command due to open the HTML file for
 * user help.
 * ****************************************************************************
 *)
var
     CodeStr        : String;
begin
  if Code<32 then begin
    str(Code, CodeStr);
    MessageDlg('Could not shellexecute "'+FileName+'".'+chr($0D)+
      'Return Code was '+CodeStr+' .', mtWarning, [mbOK],0);
  end;
end;


procedure TformMain.BrowseHelp(FileName:String);
var
  Ans       : word;
  ExeDir : String;
  ExeStr : PChar;
begin
  ExeDir:=ExtractFileDir(ParamStr(0));
  ExeStr:=PChar(ExeDir+'\'+FileName);
  Ans:=ShellExecute(Handle, 'open', ExeStr, nil, nil, SW_SHOWNORMAL);
  DisplayResult(Ans, FileName);
end;



procedure TformMain.menuHelpInEngClick(Sender: TObject);
(* ****************************************************************************
 * Opens user help written in English.
 * The program uses HTML files for help.  Users need a web browser such as
 * Netscape Navigator or Internet Explorer.
 * ****************************************************************************
 *)
begin
  BrowseHelp('j2j.html');
end;
(*
const
  FileName = '..\manual\j2j.html';
var
  Ans       : word;
begin
     Ans:=ShellExecute(Handle, 'open', FileName, nil, nil, SW_SHOWNORMAL);
     DisplayResult(Ans, FileName);
end;
*)


procedure TformMain.menuHelpInJapClick(Sender: TObject);
(* ****************************************************************************
 * Opens user help written in English.
 * The program uses HTML files for help.  Users need a web browser such as
 * Netscape Navigator or Internet Explorer.
 * ****************************************************************************
 *)
begin
  BrowseHelp('j2j-j.html');
end;

(*
const
  FileName = '..\manual\j2j-j.html';
var
  Ans       : word;
  ExeDir : String;
  ExeStr : PChar;
begin
  ExeDir:=ExtractFileDir(ParamStr(0));
  ExeStr:=PChar(ExeDir+'\'+FileName);
  Ans:=ShellExecute(Handle, 'open', ExeStr, nil, nil, SW_SHOWNORMAL);
  DisplayResult(Ans, FileName);
end;
*)
procedure TformMain.menuOptionDeleteRegistryClick(Sender: TObject);
(* ****************************************************************************
 * Removes registries for this program.
 * ****************************************************************************
 *)
var
  Mess : String;
begin
  if ExistKey(BaseKeyName) then begin
    Delete_Key(BaseKeyName);
    Mess:='It is just deleted.'+chr($0D)+'It will be re-create when program starts.';
    MessageDlg(Mess,mtInformation,[mbOK],0);
  end
  else begin
    Mess:='Target registry is not existed.';
    MessageDlg(Mess,mtInformation,[mbOK],0);
  end;
end;

procedure TformMain.menuOptionAutoDirClick(Sender: TObject);
begin
  AutoDir:=not(AutoDir);
  menuOptionAutoDir.Checked:=AutoDir;
end;

procedure TformMain.menuFileExitClick(Sender: TObject);
begin
  Close;
end;

procedure TformMain.menuIgnoreSizeSettingClick(Sender: TObject);
begin
  formignoreSizeSetting.Show;
end;

procedure TformMain.menuDisplayLogViewerClick(Sender: TObject);
begin
  formLogViewer.Show;
end;

procedure TformMain.menuOptionWarningClick(Sender: TObject);
begin
  Warning:=not(Warning);
  menuOptionWarning.Checked:=Warning;
end;


procedure TformMain.directorylistboxThumbnailChange(Sender: TObject);
var
  DelimitCount: Integer;
  I : Integer;
  L : Integer;
  Mess : String;
  OriginalDir : String;
  ThumbnailDir: String;
begin
  OriginalDir:=directorylistboxOriginal.Directory;
  ThumbnailDir:=directorylistboxThumbnail.Directory;
  if Pos(OriginalDir,ThumbnailDir)=0 then begin
    Mess:='Thumbnail directory must be under Original Dir('+OriginalDir+').';
    MessageDlg(Mess,mtWarning,[mbOK],0);
    directorylistboxThumbnail.Directory:=OriginalDir;
    directorylistboxThumbnail.Update;
  end
  else begin
    Delete(ThumbnailDir, 1, Length(OriginalDir));
    L:=Length(ThumbnailDir);
    if L>0 then begin
      DelimitCount:=0;
      for I:=1 to L do begin
        if copy(ThumbnailDir,I,1)='\' then inc(DelimitCount);
      end;
      if DelimitCount>1 then begin
        Mess:='Thumbnail directory is too deep.  Only one level lower directory is permitted.';
        MessageDlg(Mess,mtWarning,[mbOK],0);
        directorylistboxThumbnail.Directory:=OriginalDir;
        directorylistboxThumbnail.Update;
      end;
    end;
  end;
end;

procedure TformMain.menuDisplayHTMLSettingClick(Sender: TObject);
begin
  formHTML.Show;
end;

procedure TformMain.FormActivate(Sender: TObject);
var
  DriveLetter : String[1];
  Preamble : String;
  Postamble : String;
begin
  if ParamCount=0 then Exit;

//messagedlg('ParamCount='+IntToStr(ParamCount),mtInformation,[mbOK],0);

  if ParamCount=6 then begin
//messagedlg('Parameter enable',mtInformation,[mbOK],0);
    editSizeX.Text:=ParamStr(3);
    editSizeY.Text:=ParamStr(4);
    Preamble:=ParamStr(5);
    Postamble:=ParamStr(6);
    if Preamble='NULL' then Preamble:='';
    if Postamble='NULL' then Postamble:='';
    editPreamble.Text:=Preamble;
    editPostamble.Text:=Postamble;
    DriveLetter:=Copy(ParamStr(1),1,1);
    try
      drivecomboboxOriginal.Drive:=Char(DriveLetter[1]);
      directorylistboxOriginal.Directory:=ParamStr(1);
    except
      Application.Terminate;
    end;

    DriveLetter:=Copy(ParamStr(2),1,1);
    try
      directorylistboxThumbnail.Drive:=Char(DriveLetter[1]);
      directorylistboxThumbnail.Directory:=ParamStr(2);
    except
      Application.Terminate;
    end;
    menuFileSelectAllClick(Sender);
    menuFileSaveClick(Sender);
    Application.Terminate;
  end
  else begin
    //messagedlg('halt',mtInformation,[mbOK],0);
    Application.Terminate;
  end;
end;

end.
